import DropDownFilter from "../components/DropDownFilter";
import {useEffect, useState} from "react";
import useGrowbrosFetcher from "../utils/useGrowbrosFetcher";
import {Plant} from "../utils/schemas";
import {IBackendConnector} from "../utils/IBackendConnector";
import PlantsOverview from "../components/PlantsOverview";

function Garten() {
  const [plants, setPlantsInGarden] = useState<Plant[]>([]);
  const [error, setError] = useState({});
  const bc: IBackendConnector = useGrowbrosFetcher();

  useEffect(() => {
    (async () => {
      const result = await bc.getGardenEntries();
      if (result.err) {
        setError(result.err);
      } else {
        setPlantsInGarden(result.value!);
      }
    })();
  }, []);

  return (
      <>
          <div style={{padding: "20px"}}>
              <h2>Dein Garten</h2>
              <DropDownFilter
                  topic={"Sortierung der Pflanzen im Garten"}
                  options={[
                      "neueste zuerst",
                      "als nächstes anpflanzbar",
                      "als nächstes erntbar",
                  ]}
              />
          </div>
      <PlantsOverview plants={plants} />
      </>
  );
}

export default Garten;
